/*
** Copyright (©) 2003-2009 Teus Benschop.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 3 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
**  
*/


#ifndef INCLUDED_GUI_H
#define INCLUDED_GUI_H


#include "libraries.h"
#include <gtk/gtk.h>


void gui_okay (GtkWidget * image, GtkWidget * label, bool ok);
bool gui_double_question (GtkWidget * parent, ustring question1, ustring question2);
ustring gui_book_selection_information (const ustring& project);


#endif
